@@ -23,20 +23,18 @@
 #include <QTreeView>
 #include <QDateTime>
 
-#include <kapplication.h>
+#include <qapplication.h>
 #include <kconfigdialog.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kscoredialog.h>
+#include <highscore/kscoredialog.h>
 #include <kstandardaction.h>
 #include <kstandardgameaction.h>
 #include <kactioncollection.h>
-#include <kaction.h>
-#include <KStatusBar>
+#include <QAction>
+#include <QStatusBar>
 #include <KToggleAction>
 #include <KToolBar>
-#include <kdeprintdialog.h>
-
 #include "computer.h"
 #include "configwidget.h"
 #include "lateralwidget.h"
@@ -79,28 +77,28 @@ kiriki::kiriki() : KXmlGuiWindow(), m_hintGiven(false)
 	QFontMetrics fm(f);
 	m_scoresWidget -> header() -> setMinimumSectionSize(fm.width("9999"));
 
-	connect(m_scoresWidget, SIGNAL(pressed(QModelIndex)), this, SLOT(pressed(QModelIndex)));
+	connect(m_scoresWidget, &QTreeView::pressed, this, &kiriki::pressed);
 	lay -> addWidget(m_scoresWidget, 1);
 	
 	m_scores = 0;
 	
 	// Game
-	KAction *gameNewAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
+	QAction *gameNewAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
 	KStandardGameAction::highscores(this, SLOT(showHighScores()), actionCollection());
 	KStandardGameAction::print(this, SLOT(print()), actionCollection());
-	KStandardGameAction::quit(kapp, SLOT(quit()), actionCollection());
+	KStandardGameAction::quit(qApp, SLOT(quit()), actionCollection());
 	m_hintAction = KStandardGameAction::hint(this, SLOT(showHint()), actionCollection());
 	m_demoAction = KStandardGameAction::demo(this, SLOT(demo()), actionCollection());
-	connect(gameNewAction, SIGNAL(triggered(bool)), m_demoAction, SLOT(setChecked(bool)));
-	connect(gameNewAction, SIGNAL(triggered(bool)), m_demoAction, SLOT(setDisabled(bool)));
-	connect(gameNewAction, SIGNAL(triggered(bool)), m_hintAction, SLOT(setDisabled(bool)));
-	connect(gameNewAction, SIGNAL(triggered(bool)), m_lateral, SLOT(disableDemoMode()));
-	connect(gameNewAction, SIGNAL(triggered(bool)), m_lateral, SLOT(unhighlightAllDice()));
-	connect(this, SIGNAL(demoStarted(bool)), m_demoAction, SLOT(setDisabled(bool)));
-	connect(this, SIGNAL(demoStarted(bool)), m_demoAction, SLOT(setChecked(bool)));
-	connect(this, SIGNAL(demoStarted(bool)), m_hintAction, SLOT(setDisabled(bool)));
-	connect(this, SIGNAL(demoStarted(bool)), m_lateral, SLOT(unhighlightAllDice()));
-	connect(m_lateral, SIGNAL(newGameClicked()), gameNewAction, SLOT(trigger()));
+	connect(gameNewAction, &QAction::triggered, m_demoAction, &KToggleAction::setChecked);
+	connect(gameNewAction, &QAction::triggered, m_demoAction, &KToggleAction::setDisabled);
+	connect(gameNewAction, &QAction::triggered, m_hintAction, &QAction::setDisabled);
+	connect(gameNewAction, &QAction::triggered, m_lateral, &lateralWidget::disableDemoMode);
+	connect(gameNewAction, &QAction::triggered, m_lateral, &lateralWidget::unhighlightAllDice);
+	connect(this, &kiriki::demoStarted, m_demoAction, &KToggleAction::setDisabled);
+	connect(this, &kiriki::demoStarted, m_demoAction, &KToggleAction::setChecked);
+	connect(this, &kiriki::demoStarted, m_hintAction, &QAction::setDisabled);
+	connect(this, &kiriki::demoStarted, m_lateral, &lateralWidget::unhighlightAllDice);
+	connect(m_lateral, &lateralWidget::newGameClicked, gameNewAction, &QAction::trigger);
 	
 	// Preferences
 	KStandardAction::preferences(this, SLOT(showPreferences()), actionCollection());
@@ -326,8 +324,7 @@ void kiriki::showPreferences()
 	KConfigDialog *configDialog = new KConfigDialog(this, "settings", kirikiSettings::self());
 	configDialog->setFaceType(KConfigDialog::Plain);
 	configDialog -> addPage(new configWidget(configDialog), QString(), QString());
-        configDialog->setHelp(QString(),"kiriki");
-	connect( configDialog, SIGNAL(settingsChanged(QString)), this, SLOT(settingsChanged()) );
+	connect(configDialog, &KConfigDialog::settingsChanged, this, &kiriki::settingsChanged);
 	configDialog -> exec();
 	delete configDialog;
 
@@ -353,7 +350,7 @@ void kiriki::print()
 {
 	QPrinter printer;
 	printer.setFullPage( true );
-	QPrintDialog *printDialog = KdePrint::createPrintDialog(&printer, this);
+	QPrintDialog *printDialog = new QPrintDialog(&printer, this);
 	if (printDialog->exec())
 	{
 		QPainter painter(&printer);
@@ -406,4 +403,4 @@ void kiriki::playComputer()
 	else m_lateral -> setEnabled(true);
 }
 
-#include "kiriki.moc"
+
